# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/regreg/ertgretg/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Regreg\\Ertgretg\\": "packages/regreg/ertgretg/src",
            "Regreg\\Ertgretg\\Seeders\\": "packages/regreg/ertgretg/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Regreg\Ertgretg\Providers\ErtgretgServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Ertgretg'  => Regreg\Ertgretg\Facades\Ertgretg::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Regreg\\Ertgretg\\Seeders\\ErtgretgTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Regreg\Ertgretg\Providers\ErtgretgServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Regreg\Ertgretg\Providers\ErtgretgServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Regreg\Ertgretg\Providers\ErtgretgServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/ertgretg/{modulename}

**User**

    http://path-to-route-folder/user/ertgretg/{modulename}

**Public**

    http://path-to-route-folder/ertgretgs


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/ertgretg/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/ertgretg/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/ertgretg/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/ertgretg/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/ertgretg/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/ertgretg/{modulename}/{slug}
    METHOD: GET